@@ -27,6 +27,8 @@ sub startup {
   $r->get('/posts/create')->to('posts#create')->name('create_post');
   $r->post('/posts')->to('posts#store')->name('store_post');
   $r->get('/posts/:id')->to('posts#show')->name('show_post');
+  $r->get('/posts/:id/edit')->to('posts#edit')->name('edit_post');
+  $r->put('/posts/:id')->to('posts#update')->name('update_post');
   $r->delete('/posts/:id')->to('posts#remove')->name('remove_post');
 }
 
